import * as OraMultiPromise from './ora-multi-promise/index.js';
import run from './run/run.js';
import { makeQueryablePromise } from 'promise-with-state';
import resolveValue from 'resolve-value';
import logTree from 'console-log-tree';
import { basename } from 'path';
/**
 * Like `run`, but used in the cli, and outputs to console.
 */
const cliRun = (options) => {
    const oraMultiPromise = OraMultiPromise.initialize({
        taskName: `Create index${options.indexFileExtension}`
    });
    const result = run(options);
    const showResult = (result) => {
        OraMultiPromise.add(oraMultiPromise, makeQueryablePromise((async () => {
            const subDirs = await result.subDirs;
            subDirs.forEach(result => showResult(result));
        })()));
    };
    showResult(result);
    resolveValue(result).then(result => {
        console.log(`Created index${options.indexFileExtension} files for the following dirs`);
        const getTree = ({ dir, subDirs, createdIndexFile }) => ({
            name: `${basename(dir)} ${createdIndexFile ? '\u{2714}' : '\u{274C}'}`,
            children: subDirs.map(dirs => getTree(dirs))
        });
        // const mappedDirs = recursiveMap<string>(dirs, dir => basename(dir)) as Dirs
        const tree = getTree(result);
        logTree.log(tree);
    });
};
export default cliRun;
