import createIndex from '../createIndex/createIndex.js';
import { join, basename } from 'path';
import { readdir } from 'fs/promises';
import resolveValue from 'resolve-value';
import getFilesToImport from '../getFilesToImport.js';
/**
 * This function is useful for using programmatically
 */
const run = (options) => {
    const processDir = (dir) => {
        const filesPromise = readdir(dir, { withFileTypes: true });
        const subDirsPromise = (async () => {
            if (options.recursive) {
                return (await filesPromise)
                    .filter(file => file.isDirectory())
                    .map(({ name }) => name)
                    .map(subDir => processDir(join(dir, subDir)));
            }
            return [];
        })();
        const createdIndexFilePromise = (async () => {
            const subDirs = await resolveValue(subDirsPromise);
            return await createIndex({
                dir,
                files: getFilesToImport(options.extensions, (await filesPromise)
                    .filter(file => file.isFile())
                    .map(file => file.name)),
                subDirsToInclude: new Set(subDirs
                    .filter(({ createdIndexFile }) => createdIndexFile)
                    .map(({ dir }) => basename(dir))),
                force: options.force,
                indexFileExtension: options.indexFileExtension,
                tsNodeNext: options.tsNodeNext
            });
        })();
        return {
            dir,
            createdIndexFile: createdIndexFilePromise,
            subDirs: subDirsPromise
        };
    };
    return processDir(options.dir);
};
export default run;
